# DRAPI-Lemur
 
 DRAPI Lemur is a data request API for the IDR. To distinguish it from other similar data request API repositories, this one has been designated "Lemur", in honor of the IDR's affinity for tree-dwelling mammals 🦥.
